@@ -7,13 +7,19 @@ import hashlib
 import rename_lock
 from sout import sout, souts
 
+# 索引が存在するか調べる (編集中も含む)
+def check_index_exists(db_dir):
+	for filename in fies[db_dir]:
+		if filename.startswith("index.json"): return True
+	return False
+
 # DBディレクトリが存在しないときに作成
 def make_db_dir(db_dir):
 	# ディレクトリが存在しない場合に作成
 	if os.path.exists(db_dir) is False: os.mkdir(db_dir)
 	# 索引が存在しない場合に作成
-	index_filename = os.path.join(db_dir, "index.json")
-	if os.path.exists(index_filename) is False:
+	if check_index_exists(db_dir) is False:	# 索引が存在するか調べる (編集中も含む)
+		index_filename = os.path.join(db_dir, "index.json")
 		fies[index_filename] = {}
 	# dataディレクトリが存在しない場合に作成
 	data_dir = os.path.join(db_dir, "data")
